@@ -24,7 +24,6 @@
 #define __E_MINICARD_H__
 
 #include <gtk/gtk.h>
-#include "addressbook/gui/contact-editor/eab-editor.h"
 #include <libgnomecanvas/gnome-canvas.h>
 #include <libebook/e-contact.h>
 
@@ -69,9 +68,7 @@ struct _EMinicard
 	GnomeCanvasItem *list_icon;
 
 	GdkPixbuf *list_icon_pixbuf;
-	double list_icon_size;
-
-	EABEditor *editor;
+	gdouble list_icon_size;
 
 	GList *fields; /* Of type EMinicardField */
 	guint needs_remodeling : 1;
@@ -91,8 +88,8 @@ struct _EMinicard
 	gint button_x;
 	gint button_y;
 
-	double width;
-	double height;
+	gdouble width;
+	gdouble height;
 };
 
 struct _EMinicardClass
@@ -101,6 +98,7 @@ struct _EMinicardClass
 
 	gint (* selected) (EMinicard *minicard, GdkEvent *event);
 	gint (* drag_begin) (EMinicard *minicard, GdkEvent *event);
+	void (* open_contact) (EMinicard *minicard, EContact *contact);
 
 	void (* style_set) (EMinicard *minicard, GtkStyle *previous_style);
 };
@@ -121,7 +119,7 @@ gint         e_minicard_compare      (EMinicard *minicard1,
 
 gint         e_minicard_selected     (EMinicard *minicard,
 				     GdkEvent  *event);
-gboolean    e_minicard_activate_editor	(EMinicard *minicard);
+void        e_minicard_activate_editor	(EMinicard *minicard);
 
 G_END_DECLS
 
