@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -168,7 +168,7 @@ all_rows_deleted (EDateTimeList *date_time_list)
 	i = g_list_length (date_time_list->list);
 	gtk_tree_path_append_index (path, i);
 
-	for ( ; i >= 0; i--) {
+	for (; i >= 0; i--) {
 		gtk_tree_model_row_deleted (GTK_TREE_MODEL (date_time_list), path);
 		gtk_tree_path_prev (path);
 	}
@@ -398,10 +398,10 @@ e_date_time_list_get_path (GtkTreeModel *tree_model,
 }
 
 /* Builds a static string out of an exception date */
-static char *
+static gchar *
 get_exception_string (ECalComponentDateTime *dt)
 {
-	static char buf [256];
+	static gchar buf [256];
 	struct tm tmp_tm;
 
 	tmp_tm.tm_year  = dt->value->year - 1900;
