@@ -33,7 +33,7 @@
 #include <libecal/e-cal.h>
 #include <shell/e-shell-settings.h>
 
-#include "e-calendar-table.h"
+#include "e-cal-model.h"
 
 /* Standard GObject macros */
 #define GNOME_TYPE_CALENDAR \
@@ -93,19 +93,23 @@ struct _GnomeCalendarClass {
 	GtkVBoxClass parent_class;
 
 	/* Notification signals */
-	void (* dates_shown_changed)    (GnomeCalendar *gcal);
+	void	(*dates_shown_changed)		(GnomeCalendar *gcal);
 
-	void (* calendar_selection_changed) (GnomeCalendar *gcal);
+	void	(*calendar_selection_changed)	(GnomeCalendar *gcal);
 
-	void (* calendar_focus_change)  (GnomeCalendar *gcal, gboolean in);
-	void (* change_view) (GnomeCalendar *gcal,
-			       GnomeCalendarViewType view_type);
+	void	(*calendar_focus_change)	(GnomeCalendar *gcal,
+						 gboolean in);
+	void	(*change_view)			(GnomeCalendar *gcal,
+						 GnomeCalendarViewType view_type);
 
-        void (* source_added)           (GnomeCalendar *gcal, ESource *source);
-        void (* source_removed)         (GnomeCalendar *gcal, ESource *source);
+	void	(*source_added)			(GnomeCalendar *gcal,
+						 ESource *source);
+	void	(*source_removed)		(GnomeCalendar *gcal,
+						 ESource *source);
 
 	/* Action signals */
-        void (* goto_date)              (GnomeCalendar *gcal, GnomeCalendarGotoDateType date);
+        void	(*goto_date)			(GnomeCalendar *gcal,
+						 GnomeCalendarGotoDateType date);
 };
 
 GType		gnome_calendar_get_type		(void);
@@ -118,14 +122,6 @@ void		gnome_calendar_set_date_navigator
 						(GnomeCalendar *gcal,
 						 ECalendar *date_navigator);
 ECalModel *	gnome_calendar_get_model	(GnomeCalendar *gcal);
-gboolean	gnome_calendar_remove_source	(GnomeCalendar *gcal,
-						 ESource *source);
-gboolean	gnome_calendar_remove_source_by_uid
-						(GnomeCalendar *gcal,
-						 const gchar *uid);
-gboolean	gnome_calendar_set_default_source
-						(GnomeCalendar *gcal,
-						 ESource *source);
 void		gnome_calendar_update_query	(GnomeCalendar *gcal);
 void		gnome_calendar_set_search_query	(GnomeCalendar *gcal,
 						 const gchar *sexp,
