@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -20,8 +20,13 @@
  *
  */
 
-#ifndef _E_UTIL_H_
-#define _E_UTIL_H_
+/**
+ * SECTION: e-util
+ * @include: e-util/e-util.h
+ **/
+
+#ifndef E_UTIL_H
+#define E_UTIL_H
 
 #include <sys/types.h>
 #include <gtk/gtk.h>
@@ -32,6 +37,11 @@
 
 #include <e-util/e-marshal.h>
 
+/* Convenience macro to help migrate from libglade to GtkBuilder.
+ * Use it as a direct replacement for glade_xml_get_widget(). */
+#define e_builder_get_widget(builder, name) \
+	GTK_WIDGET (gtk_builder_get_object ((builder), (name)))
+
 G_BEGIN_DECLS
 
 typedef enum {
@@ -41,6 +51,8 @@ typedef enum {
 	E_FOCUS_END
 } EFocus;
 
+typedef void (*ETypeFunc) (GType type, gpointer user_data);
+
 const gchar *	e_get_user_data_dir		(void);
 const gchar *	e_get_accels_filename		(void);
 void		e_show_uri			(GtkWindow *parent,
@@ -51,14 +63,23 @@ GtkAction *	e_lookup_action			(GtkUIManager *ui_manager,
 						 const gchar *action_name);
 GtkActionGroup *e_lookup_action_group		(GtkUIManager *ui_manager,
 						 const gchar *group_name);
-guint		e_load_ui_definition		(GtkUIManager *ui_manager,
+void		e_load_ui_builder_definition	(GtkBuilder *builder,
+						 const gchar *basename);
+guint		e_load_ui_manager_definition	(GtkUIManager *ui_manager,
 						 const gchar *basename);
 gint		e_action_compare_by_label	(GtkAction *action1,
 						 GtkAction *action2);
 void		e_action_group_remove_all_actions
 						(GtkActionGroup *action_group);
+GtkRadioAction *e_radio_action_get_current_action
+						(GtkRadioAction *radio_action);
+void		e_categories_add_change_hook	(GHookFunc func,
+						 gpointer object);
+void		e_type_traverse			(GType parent_type,
+						 ETypeFunc func,
+						 gpointer user_data);
 
-char *		e_str_without_underscores	(const char *s);
+gchar *		e_str_without_underscores	(const gchar *string);
 gint		e_str_compare			(gconstpointer x,
 						 gconstpointer y);
 gint		e_str_case_compare		(gconstpointer x,
@@ -67,16 +88,15 @@ gint		e_collate_compare		(gconstpointer x,
 						 gconstpointer y);
 gint		e_int_compare                   (gconstpointer x,
 						 gconstpointer y);
-gboolean	e_write_file_uri		(const gchar *filename,
-						 const gchar *data);
+guint32		e_color_to_value		(GdkColor *color);
 
 /* This only makes a filename safe for usage as a filename.
  * It still may have shell meta-characters in it. */
 gchar *		e_format_number			(gint number);
 
 typedef gint	(*ESortCompareFunc)		(gconstpointer first,
-				  		 gconstpointer second,
-				  		 gpointer closure);
+						 gconstpointer second,
+						 gpointer closure);
 
 void		e_bsearch			(gconstpointer key,
 						 gconstpointer base,
@@ -113,33 +133,21 @@ gchar *		e_ascii_dtostr			(gchar *buffer,
 						 const gchar *format,
 						 gdouble d);
 
-/* Alternating char * and int arguments with a NULL char * to end.
-   Less than 0 for the int means copy the whole string. */
-gchar *		e_strdup_append_strings		(gchar *first_string,
-						 ...);
-
 cairo_font_options_t *
 		get_font_options		(void);
 
-void		e_file_update_save_path		(gchar *uri,
-						 gboolean free);
-gchar *		e_file_get_save_path		(void);
-
 gboolean	e_file_lock_create		(void);
 void		e_file_lock_destroy		(void);
-gboolean 	e_file_lock_exists		(void);
+gboolean	e_file_lock_exists		(void);
 
-gchar *		e_util_guess_mime_type		(const gchar *filename, gboolean localfile);
-gchar *		e_util_filename_to_uri		(const gchar *filename);
-gchar *		e_util_uri_to_filename		(const gchar *uri);
+gchar *		e_util_guess_mime_type		(const gchar *filename,
+                                                 gboolean localfile);
 
-gboolean	e_util_read_file		(const gchar *filename,
-						 gboolean filename_is_uri,
-						 gchar **buffer,
-						 gsize *read,
-						 GError **error);
+GSList *	e_util_get_category_filter_options
+						(void);
 
-GSList *e_util_get_category_filter_options      (void);
+void		e_util_set_source_combo_box_list(GtkWidget *source_combo_box,
+						 const gchar *source_gconf_path);
 
 /* Camel uses its own object system, so we have to box
  * CamelObjects to safely use them as GObject properties. */
@@ -148,4 +156,4 @@ GType		e_camel_object_get_type		(void);
 
 G_END_DECLS
 
-#endif /* _E_UTIL_H_ */
+#endif /* E_UTIL_H */
