@@ -105,9 +105,11 @@ action_add_to_address_book_cb (GtkAction *action,
 	EShell *shell;
 	EShellBackend *shell_backend;
 	EMFormatHTMLDisplay *html_display;
+	CamelInternetAddress *cia;
 	EWebView *web_view;
 	CamelURL *curl;
 	const gchar *uri;
+	gchar *email;
 
 	/* This action is defined in EMailDisplay. */
 
@@ -125,11 +127,23 @@ action_add_to_address_book_cb (GtkAction *action,
 	if (curl->path == NULL || *curl->path == '\0')
 		goto exit;
 
+	cia = camel_internet_address_new ();
+	if (camel_address_decode (CAMEL_ADDRESS (cia), curl->path) < 0) {
+		camel_object_unref (cia);
+		goto exit;
+	}
+
+	email = camel_address_format (CAMEL_ADDRESS (cia));
+
 	/* XXX EBookShellBackend should be listening for this
 	 *     event.  Kind of kludgey, but works for now. */
 	shell = e_shell_backend_get_shell (shell_backend);
-	e_shell_event (shell, "contact-quick-add-email", curl->path);
+	e_shell_event (shell, "contact-quick-add-email", email);
 	emu_remove_from_mail_cache_1 (curl->path);
+
+	camel_object_unref (cia);
+	g_free (email);
+
 exit:
 	camel_url_free (curl);
 }
@@ -1633,12 +1647,12 @@ mail_reader_key_press_event_cb (EMailReader *reader,
 			break;
 
 		case GDK_period:
-		case GDK_bracketleft:
+		case GDK_bracketright:
 			action_name = "mail-next-unread";
 			break;
 
 		case GDK_comma:
-		case GDK_bracketright:
+		case GDK_bracketleft:
 			action_name = "mail-previous-unread";
 			break;
 
@@ -1726,6 +1740,10 @@ update_webview_content (EMailReader *reader, const gchar *content)
 	html_display = e_mail_reader_get_html_display (reader);
 	g_return_if_fail (html_display != NULL);
 
+	/* skip the progress message when it's formatting something */
+	if (em_format_busy (EM_FORMAT (html_display)))
+		return;
+
 	web_view = E_WEB_VIEW (EM_FORMAT_HTML (html_display)->html);
 	g_return_if_fail (web_view != NULL);
 
