@@ -1067,13 +1067,14 @@ emu_update_composers_security (EMsgComposer *composer, guint32 validity_found)
 
 	g_return_if_fail (composer != NULL);
 
-	if (validity_found & EM_FORMAT_VALIDITY_FOUND_SIGNED) {
+	/* Pre-set only for encrypted messages, not for signed */
+	/*if (validity_found & EM_FORMAT_VALIDITY_FOUND_SIGNED) {
 		if (validity_found & EM_FORMAT_VALIDITY_FOUND_SMIME)
 			action = GTK_TOGGLE_ACTION (E_COMPOSER_ACTION_SMIME_SIGN (composer));
 		else
 			action = GTK_TOGGLE_ACTION (E_COMPOSER_ACTION_PGP_SIGN (composer));
 		gtk_toggle_action_set_active (action, TRUE);
-	}
+	}*/
 
 	if (validity_found & EM_FORMAT_VALIDITY_FOUND_ENCRYPTED) {
 		if (validity_found & EM_FORMAT_VALIDITY_FOUND_SMIME)
@@ -1541,6 +1542,9 @@ em_utils_send_receipt (CamelFolder *folder, CamelMimeMessage *message)
 	if (!receipt_address)
 		return;
 
+	/* the 'account' should be always set */
+	g_return_if_fail (account != NULL);
+
 	/* Collect information for the receipt */
 
 	/* We use camel_header_msgid_generate () to get a canonical
@@ -1632,14 +1636,9 @@ em_utils_send_receipt (CamelFolder *folder, CamelMimeMessage *message)
 	camel_object_unref (addr);
 
 	camel_medium_set_header (CAMEL_MEDIUM (receipt), "Return-Path", "<>");
-	if (account) {
-		camel_medium_set_header (CAMEL_MEDIUM (receipt),
-					"X-Evolution-Account", account->uid);
-		camel_medium_set_header (CAMEL_MEDIUM (receipt),
-					"X-Evolution-Transport", account->transport->url);
-		camel_medium_set_header (CAMEL_MEDIUM (receipt),
-					"X-Evolution-Fcc",  account->sent_folder_uri);
-	}
+	camel_medium_set_header (CAMEL_MEDIUM (receipt), "X-Evolution-Account", account->uid);
+	camel_medium_set_header (CAMEL_MEDIUM (receipt), "X-Evolution-Transport", account->transport->url);
+	camel_medium_set_header (CAMEL_MEDIUM (receipt), "X-Evolution-Fcc",  account->sent_folder_uri);
 
 	/* Send the receipt */
 	info = camel_message_info_new (NULL);
@@ -1946,7 +1945,7 @@ static void
 format_sender (GString *str, const gchar *attr, CamelMimeMessage *message)
 {
 	const CamelInternetAddress *sender;
-	const gchar *name, *addr;
+	const gchar *name, *addr = NULL;
 
 	sender = camel_mime_message_get_from (message);
 	if (sender != NULL && camel_address_length (CAMEL_ADDRESS (sender)) > 0) {
@@ -2033,7 +2032,7 @@ attribution_format (const gchar *format, CamelMimeMessage *message)
 
 	gmtime_r (&date, &tm);
 
-	start = inptr = format;
+	inptr = format;
 	while (*inptr != '\0') {
 		start = inptr;
 		while (*inptr && strncmp (inptr, "${", 2) != 0)
