@@ -1,22 +1,22 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Authors: Michael Zucchi <notzed@ximian.com>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Authors:
+ *		Michael Zucchi <notzed@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -33,7 +33,6 @@
 
 #include <glib/gi18n.h>
 
-
 /* class name -> klass map for EMFormat and subclasses */
 static GHashTable *emfh_types;
 
@@ -52,7 +51,7 @@ static GHashTable *emfh_types;
 
 */
 
-static void *emfh_parent_class;
+static gpointer emfh_parent_class;
 #define emfh ((EMFormatHook *)eph)
 
 #define d(x)
@@ -64,7 +63,10 @@ static const EPluginHookTargetKey emfh_flag_map[] = {
 };
 
 static void
-emfh_format_format(EMFormat *md, struct _CamelStream *stream, struct _CamelMimePart *part, const EMFormatHandler *info)
+emfh_format_format (EMFormat *md,
+                    CamelStream *stream,
+                    CamelMimePart *part,
+                    const EMFormatHandler *info)
 {
 	struct _EMFormatHookItem *item = (EMFormatHookItem *)info;
 
@@ -141,7 +143,7 @@ emfh_construct_group(EPluginHook *eph, xmlNodePtr root)
 
 	node = root->children;
 	while (node) {
-		if (0 == strcmp((char *)node->name, "item")) {
+		if (0 == strcmp((gchar *)node->name, "item")) {
 			struct _EMFormatHookItem *item;
 
 			item = emfh_construct_item(eph, group, node);
@@ -157,7 +159,7 @@ error:
 	return NULL;
 }
 
-static int
+static gint
 emfh_construct(EPluginHook *eph, EPlugin *ep, xmlNodePtr root)
 {
 	xmlNodePtr node;
@@ -169,7 +171,7 @@ emfh_construct(EPluginHook *eph, EPlugin *ep, xmlNodePtr root)
 
 	node = root->children;
 	while (node) {
-		if (strcmp((char *)node->name, "group") == 0) {
+		if (strcmp((gchar *)node->name, "group") == 0) {
 			struct _EMFormatHookGroup *group;
 
 			group = emfh_construct_group(eph, node);
@@ -183,8 +185,10 @@ emfh_construct(EPluginHook *eph, EPlugin *ep, xmlNodePtr root)
 					for (;l;l=g_slist_next(l)) {
 						EMFormatHookItem *item = l->data;
 						/* TODO: only add handlers if enabled? */
-						/* Well, disabling is handled by the callback, if we leave as is,
-						   then we can enable the plugin after startup and it will start working automagically */
+						/* Well, disabling is handled by the callback,
+						 * if we leave as is, then we can enable the
+						 * plugin after startup and it will start
+						 * working automagically */
 						em_format_class_add_handler(klass, &item->handler);
 					}
 				}
@@ -203,7 +207,7 @@ emfh_construct(EPluginHook *eph, EPlugin *ep, xmlNodePtr root)
 }
 
 static void
-emfh_enable(EPluginHook *eph, int state)
+emfh_enable(EPluginHook *eph, gint state)
 {
 	GSList *g, *l;
 	EMFormatClass *klass;
@@ -275,5 +279,5 @@ void em_format_hook_register_type(GType type)
 	d(printf("registering formatter type '%s'\n", g_type_name(type)));
 
 	klass = g_type_class_ref(type);
-	g_hash_table_insert(emfh_types, (void *)g_type_name(type), klass);
+	g_hash_table_insert(emfh_types, (gpointer)g_type_name(type), klass);
 }
