@@ -799,10 +799,27 @@ efhd_attachment_button(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObje
 	EAttachment *attachment;
 	GtkWidget *widget;
 	gpointer parent;
+	EMFormat *emf = (EMFormat *) efh;
+	CamelMessageInfo *mi = NULL;
+	guint32 size = 0;
 
 	/* FIXME: handle default shown case */
 	d(printf("adding attachment button/content\n"));
 
+	mi = camel_folder_summary_uid (emf->folder->summary, emf->uid);
+	if (mi) {
+		const CamelMessageContentInfo *ci;
+
+		ci = camel_folder_summary_guess_content_info (mi, camel_mime_part_get_content_type (pobject->part));
+		if (ci) {
+			size = ci->size;
+			/* what if its not encoded in base64 ? is it a case to consider? */
+			if (ci->encoding && !g_ascii_strcasecmp (ci->encoding, "base64"))
+				size = size/1.37;
+		}
+		camel_message_info_free (mi);
+	}
+
 	info = (struct _attach_puri *)em_format_find_puri((EMFormat *)efh, pobject->classid);
 
 	if (!info || info->forward) {
@@ -817,7 +834,7 @@ efhd_attachment_button(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObje
 	e_attachment_set_can_show (attachment, info->handle != NULL);
 
 	parent = gtk_widget_get_toplevel (GTK_WIDGET (efh->html));
-	parent = GTK_WIDGET_TOPLEVEL (parent) ? parent : NULL;
+	parent = gtk_widget_is_toplevel (parent) ? parent : NULL;
 
 	view = em_format_html_display_get_attachment_view (efhd);
 	gtk_widget_show (GTK_WIDGET (view));
@@ -828,6 +845,13 @@ efhd_attachment_button(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObje
 	e_attachment_load_async (
 		info->attachment, (GAsyncReadyCallback)
 		e_attachment_load_handle_error, parent);
+	if (size != 0) {
+		GFileInfo *fileinfo;
+
+		fileinfo = e_attachment_get_file_info (info->attachment);
+		g_file_info_set_size (fileinfo, size);
+		e_attachment_set_file_info (info->attachment, fileinfo);
+	}
 
 	widget = e_attachment_button_new (view);
 	e_attachment_button_set_attachment (
