@@ -2091,18 +2091,33 @@ em_utils_url_unescape_amp (const gchar *url)
 }
 
 static EAccount *
-guess_account_folder (CamelFolder *folder)
+guess_account_from_folder (CamelFolder *folder)
 {
+	CamelService *service;
 	EAccount *account;
-	gchar *tmp;
+	gchar *source_url;
 
-	tmp = camel_url_to_string (CAMEL_SERVICE (folder->parent_store)->url, CAMEL_URL_HIDE_ALL);
-	account = mail_config_get_account_by_source_url (tmp);
-	g_free (tmp);
+	service = CAMEL_SERVICE (folder->parent_store);
+
+	source_url = camel_url_to_string (service->url, CAMEL_URL_HIDE_ALL);
+	account = mail_config_get_account_by_source_url (source_url);
+	g_free (source_url);
 
 	return account;
 }
 
+static EAccount *
+guess_account_from_message (CamelMimeMessage *message)
+{
+	const gchar *source_url;
+
+	source_url = camel_mime_message_get_source (message);
+	if (source_url == NULL)
+		return NULL;
+
+	return mail_config_get_account_by_source_url (source_url);
+}
+
 GHashTable *
 em_utils_generate_account_hash (void)
 {
@@ -2152,66 +2167,121 @@ em_utils_generate_account_hash (void)
 }
 
 EAccount *
-em_utils_guess_account_with_recipients (CamelMimeMessage *message, CamelFolder *folder)
+em_utils_guess_account (CamelMimeMessage *message,
+                        CamelFolder *folder)
 {
-	GHashTable *account_hash = NULL;
 	EAccount *account = NULL;
-	const gchar *tmp;
-	gint i;
-	GList *l, *recipients = NULL;
-	const CamelInternetAddress *addr;
 
-	account = em_utils_guess_account (message, folder);
-	if (account)
-		return account;
-	addr = camel_mime_message_get_recipients(message, CAMEL_RECIPIENT_TYPE_TO);
-	if (addr)
-		recipients = g_list_append (recipients, (gpointer) addr);
-	addr = camel_mime_message_get_recipients(message, CAMEL_RECIPIENT_TYPE_CC);
-	if (addr)
-		recipients = g_list_append (recipients, (gpointer) addr);
+	g_return_val_if_fail (CAMEL_IS_MIME_MESSAGE (message), NULL);
 
-	/* finally recipient (to/cc) in account table */
-	account_hash = em_utils_generate_account_hash ();
-	for (l = recipients; l == NULL; l = l->next) {
-		const CamelInternetAddress *to;
+	if (folder != NULL)
+		g_return_val_if_fail (CAMEL_IS_FOLDER (folder), NULL);
 
-		to = (CamelInternetAddress*)l->data;
-		if (to) {
-			for (i = 0; camel_internet_address_get(to, i, NULL, &tmp); i++) {
-				account = g_hash_table_lookup(account_hash, tmp);
-				if (account && account->enabled)
-					break;
-			}
-		}
-	}
-	g_hash_table_destroy(account_hash);
+	/* check for newsgroup header */
+	if (folder != NULL
+	    && camel_medium_get_header (CAMEL_MEDIUM (message), "Newsgroups"))
+		account = guess_account_from_folder (folder);
+
+	/* check for source folder */
+	if (account == NULL && folder != NULL)
+		account = guess_account_from_folder (folder);
+
+	/* then message source */
+	if (account == NULL)
+		account = guess_account_from_message (message);
 
 	return account;
 }
 
 EAccount *
-em_utils_guess_account (CamelMimeMessage *message, CamelFolder *folder)
+em_utils_guess_account_with_recipients (CamelMimeMessage *message,
+                                        CamelFolder *folder)
 {
 	EAccount *account = NULL;
-	const gchar *tmp;
+	EAccountList *account_list;
+	GHashTable *recipients;
+	EIterator *iter;
+	const CamelInternetAddress *addr;
+	const gchar *type;
+	const gchar *key;
 
-	/* check for newsgroup header */
-	if (folder
-	    && camel_medium_get_header ((CamelMedium *)message, "Newsgroups")
-	    && (account = guess_account_folder (folder)))
-		return account;
+	/* This policy is subject to debate and tweaking,
+	 * but please also document the rational here. */
 
-	/* check for source folder */
-	if (folder)
-		account = guess_account_folder (folder);
+	g_return_val_if_fail (CAMEL_IS_MIME_MESSAGE (message), NULL);
 
-	/* then message source */
-	if (account == NULL
-	    && (tmp = camel_mime_message_get_source (message))) {
-		account = mail_config_get_account_by_source_url (tmp);
+	/* Build a set of email addresses in which to test for membership.
+	 * Only the keys matter here; the values just need to be non-NULL. */
+	recipients = g_hash_table_new (g_str_hash, g_str_equal);
+
+	type = CAMEL_RECIPIENT_TYPE_TO;
+	addr = camel_mime_message_get_recipients (message, type);
+	if (addr != NULL) {
+		gint index = 0;
+
+		while (camel_internet_address_get (addr, index++, NULL, &key))
+			g_hash_table_insert (
+				recipients, (gpointer) key,
+				GINT_TO_POINTER (1));
 	}
 
+	type = CAMEL_RECIPIENT_TYPE_CC;
+	addr = camel_mime_message_get_recipients (message, type);
+	if (addr != NULL) {
+		gint index = 0;
+
+		while (camel_internet_address_get (addr, index++, NULL, &key))
+			g_hash_table_insert (
+				recipients, (gpointer) key,
+				GINT_TO_POINTER (1));
+	}
+
+	/* First Preference: We were given a folder that maps to an
+	 * enabled account, and that account's email address appears
+	 * in the list of To: or Cc: recipients. */
+
+	if (folder != NULL)
+		account = guess_account_from_folder (folder);
+
+	if (account == NULL || !account->enabled)
+		goto second_preference;
+
+	if ((key = account->id->address) == NULL)
+		goto second_preference;
+
+	if (g_hash_table_lookup (recipients, key) != NULL)
+		goto exit;
+
+second_preference:
+
+	/* Second Preference: Choose any enabled account whose email
+	 * address appears in the list to To: or Cc: recipients. */
+
+	account_list = e_get_account_list ();
+	iter = e_list_get_iterator (E_LIST (account_list));
+	while (e_iterator_is_valid (iter)) {
+		account = (EAccount *) e_iterator_get (iter);
+		e_iterator_next (iter);
+
+		if (account == NULL || !account->enabled)
+			continue;
+
+		if ((key = account->id->address) == NULL)
+			continue;
+
+		if (g_hash_table_lookup (recipients, key) != NULL) {
+			g_object_unref (iter);
+			goto exit;
+		}
+	}
+	g_object_unref (iter);
+
+	/* Last Preference: Defer to em_utils_guess_account(). */
+	account = em_utils_guess_account (message, folder);
+
+exit:
+	g_hash_table_destroy (recipients);
+
 	return account;
 }
 
