@@ -170,12 +170,17 @@ action_calendar_jump_to_cb (GtkAction *action,
                             ECalShellView *cal_shell_view)
 {
 	ECalShellContent *cal_shell_content;
+	EShellWindow *shell_window;
+	EShellView *shell_view;
 	GnomeCalendar *calendar;
 
+	shell_view = E_SHELL_VIEW (cal_shell_view);
+	shell_window = e_shell_view_get_shell_window (shell_view);
+
 	cal_shell_content = cal_shell_view->priv->cal_shell_content;
 	calendar = e_cal_shell_content_get_calendar (cal_shell_content);
 
-	goto_dialog (GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (cal_shell_content))), calendar);
+	goto_dialog (GTK_WINDOW (shell_window), calendar);
 }
 
 static void
@@ -350,14 +355,22 @@ static void
 action_calendar_refresh_cb (GtkAction *action,
                            ECalShellView *cal_shell_view)
 {
+	ECalShellContent *cal_shell_content;
+	ECalShellSidebar *cal_shell_sidebar;
+	ESourceSelector *selector;
 	ECal *client;
 	ECalModel *model;
 	ESource *source;
 	gchar *uri;
 	GError *error = NULL;
 
-	model = e_cal_shell_content_get_model (cal_shell_view->priv->cal_shell_content);
-	source = e_source_selector_peek_primary_selection (e_cal_shell_sidebar_get_selector (cal_shell_view->priv->cal_shell_sidebar));
+	cal_shell_content = cal_shell_view->priv->cal_shell_content;
+	cal_shell_sidebar = cal_shell_view->priv->cal_shell_sidebar;
+
+	model = e_cal_shell_content_get_model (cal_shell_content);
+	selector = e_cal_shell_sidebar_get_selector (cal_shell_sidebar);
+
+	source = e_source_selector_peek_primary_selection (selector);
 	g_return_if_fail (E_IS_SOURCE (source));
 
 	uri = e_source_get_uri (source);
@@ -370,7 +383,10 @@ action_calendar_refresh_cb (GtkAction *action,
 	g_return_if_fail (e_cal_get_refresh_supported (client));
 
 	if (!e_cal_refresh (client, &error) && error) {
-		g_warning ("%s: Failed to refresh '%s', %s\n", G_STRFUNC, e_source_peek_name (source), error->message);
+		g_warning (
+			"%s: Failed to refresh '%s', %s\n",
+			G_STRFUNC, e_source_peek_name (source),
+			error->message);
 		g_error_free (error);
 	}
 }
@@ -481,36 +497,6 @@ action_event_all_day_new_cb (GtkAction *action,
 		calendar_view, all_day, meeting, no_past_date);
 }
 
-static void
-action_event_clipboard_copy_cb (GtkAction *action,
-                                ECalShellView *cal_shell_view)
-{
-	ECalShellContent *cal_shell_content;
-
-	cal_shell_content = cal_shell_view->priv->cal_shell_content;
-	e_cal_shell_content_copy_clipboard (cal_shell_content);
-}
-
-static void
-action_event_clipboard_cut_cb (GtkAction *action,
-                               ECalShellView *cal_shell_view)
-{
-	ECalShellContent *cal_shell_content;
-
-	cal_shell_content = cal_shell_view->priv->cal_shell_content;
-	e_cal_shell_content_cut_clipboard (cal_shell_content);
-}
-
-static void
-action_event_clipboard_paste_cb (GtkAction *action,
-                                 ECalShellView *cal_shell_view)
-{
-	ECalShellContent *cal_shell_content;
-
-	cal_shell_content = cal_shell_view->priv->cal_shell_content;
-	e_cal_shell_content_paste_clipboard (cal_shell_content);
-}
-
 static void
 action_event_copy_cb (GtkAction *action,
                       ECalShellView *cal_shell_view)
@@ -543,7 +529,7 @@ action_event_copy_cb (GtkAction *action,
 		return;
 
 	/* Open the destination calendar. */
-	destination_client = auth_new_cal_from_source (
+	destination_client = e_auth_new_cal_from_source (
 		destination_source, E_CAL_SOURCE_TYPE_EVENT);
 	if (destination_client == NULL)
 		goto exit;
@@ -673,9 +659,17 @@ action_event_delete_cb (GtkAction *action,
                         ECalShellView *cal_shell_view)
 {
 	ECalShellContent *cal_shell_content;
+	GnomeCalendar *calendar;
+	GnomeCalendarViewType view_type;
+	ECalendarView *calendar_view;
 
 	cal_shell_content = cal_shell_view->priv->cal_shell_content;
-	e_cal_shell_content_delete_selection (cal_shell_content);
+	calendar = e_cal_shell_content_get_calendar (cal_shell_content);
+
+	view_type = gnome_calendar_get_view (calendar);
+	calendar_view = gnome_calendar_get_calendar_view (calendar, view_type);
+
+	e_selectable_delete_selection (E_SELECTABLE (calendar_view));
 }
 
 static void
@@ -683,20 +677,17 @@ action_event_delete_occurrence_cb (GtkAction *action,
                                    ECalShellView *cal_shell_view)
 {
 	ECalShellContent *cal_shell_content;
+	GnomeCalendar *calendar;
+	GnomeCalendarViewType view_type;
+	ECalendarView *calendar_view;
 
 	cal_shell_content = cal_shell_view->priv->cal_shell_content;
-	e_cal_shell_content_delete_selected_occurrence (cal_shell_content);
-}
+	calendar = e_cal_shell_content_get_calendar (cal_shell_content);
 
-static void
-action_event_delete_occurrence_all_cb (GtkAction *action,
-                                       ECalShellView *cal_shell_view)
-{
-	ECalShellContent *cal_shell_content;
+	view_type = gnome_calendar_get_view (calendar);
+	calendar_view = gnome_calendar_get_calendar_view (calendar, view_type);
 
-	/* XXX Same as "event-delete". */
-	cal_shell_content = cal_shell_view->priv->cal_shell_content;
-	e_cal_shell_content_delete_selection (cal_shell_content);
+	e_calendar_view_delete_selected_occurrence (calendar_view);
 }
 
 static void
@@ -793,7 +784,7 @@ action_event_move_cb (GtkAction *action,
 		return;
 
 	/* Open the destination calendar. */
-	destination_client = auth_new_cal_from_source (
+	destination_client = e_auth_new_cal_from_source (
 		destination_source, E_CAL_SOURCE_TYPE_EVENT);
 	if (destination_client == NULL)
 		goto exit;
@@ -1101,10 +1092,12 @@ action_event_save_as_cb (GtkAction *action,
 	client = event->comp_data->client;
 	icalcomp = event->comp_data->icalcomp;
 
-	/* To Translators: Default filename part saving an event to a file when no summary is filed, the '.ics' extension is concatenated to it */
+	/* Translators: Default filename part saving an event to a file when
+	 * no summary is filed, the '.ics' extension is concatenated to it. */
 	string = icalcomp_suggest_filename (icalcomp, _("event"));
 	file = e_shell_run_save_dialog (
-		shell, _("Save as iCalendar"), string, "*.ics:text/calendar", NULL, NULL);
+		shell, _("Save as iCalendar"), string,
+		"*.ics:text/calendar", NULL, NULL);
 	g_free (string);
 	if (file == NULL)
 		return;
@@ -1164,16 +1157,25 @@ edit_event_as (ECalShellView *cal_shell_view, gboolean as_meeting)
 		/* do it on a copy, as user can cancel changes */
 		icalcomp = icalcomponent_new_clone (icalcomp);
 
-		#define remove_all(_kind)									\
-			while (prop = icalcomponent_get_first_property (icalcomp, _kind), prop != NULL) {	\
-				icalcomponent_remove_property (icalcomp, prop);					\
-				icalproperty_free (prop);							\
-			}
+		prop = icalcomponent_get_first_property (
+			icalcomp, ICAL_ATTENDEE_PROPERTY);
+		while (prop != NULL) {
+			icalcomponent_remove_property (icalcomp, prop);
+			icalproperty_free (prop);
 
-		remove_all (ICAL_ATTENDEE_PROPERTY);
-		remove_all (ICAL_ORGANIZER_PROPERTY);
+			prop = icalcomponent_get_first_property (
+				icalcomp, ICAL_ATTENDEE_PROPERTY);
+		}
 
-		#undef remove_all
+		prop = icalcomponent_get_first_property (
+			icalcomp, ICAL_ORGANIZER_PROPERTY);
+		while (prop != NULL) {
+			icalcomponent_remove_property (icalcomp, prop);
+			icalproperty_free (prop);
+
+			prop = icalcomponent_get_first_property (
+				icalcomp, ICAL_ORGANIZER_PROPERTY);
+		}
 	}
 
 	e_calendar_view_edit_appointment (
@@ -1220,14 +1222,6 @@ action_gal_save_custom_view_cb (GtkAction *action,
 	gal_view_instance_save_as (view_instance);
 }
 
-static void
-action_search_filter_cb (GtkRadioAction *action,
-                         GtkRadioAction *current,
-                         EShellView *shell_view)
-{
-	e_shell_view_execute_search (shell_view);
-}
-
 static GtkActionEntry calendar_entries[] = {
 
 	{ "calendar-copy",
@@ -1239,9 +1233,9 @@ static GtkActionEntry calendar_entries[] = {
 
 	{ "calendar-delete",
 	  GTK_STOCK_DELETE,
+	  N_("D_elete Calendar"),
 	  NULL,
-	  NULL,
-	  NULL,  /* XXX Add a tooltip! */
+	  N_("Delete the selected calendar"),
 	  G_CALLBACK (action_calendar_delete_cb) },
 
 	{ "calendar-go-back",
@@ -1314,27 +1308,6 @@ static GtkActionEntry calendar_entries[] = {
 	  NULL,  /* XXX Add a tooltip! */
 	  G_CALLBACK (action_calendar_select_one_cb) },
 
-	{ "event-clipboard-copy",
-	  GTK_STOCK_COPY,
-	  NULL,
-	  NULL,
-	  N_("Copy the selection"),
-	  G_CALLBACK (action_event_clipboard_copy_cb) },
-
-	{ "event-clipboard-cut",
-	  GTK_STOCK_CUT,
-	  NULL,
-	  NULL,
-	  N_("Cut the selection"),
-	  G_CALLBACK (action_event_clipboard_cut_cb) },
-
-	{ "event-clipboard-paste",
-	  GTK_STOCK_PASTE,
-	  NULL,
-	  NULL,
-	  N_("Paste the clipboard"),
-	  G_CALLBACK (action_event_clipboard_paste_cb) },
-
 	{ "event-copy",
 	  NULL,
 	  N_("Cop_y to Calendar..."),
@@ -1351,9 +1324,9 @@ static GtkActionEntry calendar_entries[] = {
 
 	{ "event-delete",
 	  GTK_STOCK_DELETE,
-	  NULL,
+	  N_("_Delete Appointment"),
 	  "<Control>d",
-	  N_("Delete the appointment"),
+	  N_("Delete selected appointments"),
 	  G_CALLBACK (action_event_delete_cb) },
 
 	{ "event-delete-occurrence",
@@ -1365,10 +1338,10 @@ static GtkActionEntry calendar_entries[] = {
 
 	{ "event-delete-occurrence-all",
 	  GTK_STOCK_DELETE,
-	  N_("Delete _All Occurrences"),
+	  N_("Delete All Occ_urrences"),
 	  NULL,
 	  N_("Delete all occurrences"),
-	  G_CALLBACK (action_event_delete_occurrence_all_cb) },
+	  G_CALLBACK (action_event_delete_cb) },
 
 	{ "event-all-day-new",
 	  "stock_new-24h-appointment",
@@ -1475,7 +1448,7 @@ static EPopupActionEntry calendar_popup_entries[] = {
 	  "calendar-copy" },
 
 	{ "calendar-popup-delete",
-	  NULL,
+	  N_("_Delete"),
 	  "calendar-delete" },
 
 	{ "calendar-popup-go-today",
@@ -1502,18 +1475,6 @@ static EPopupActionEntry calendar_popup_entries[] = {
 	  NULL,
 	  "calendar-select-one" },
 
-	{ "event-popup-clipboard-copy",
-	  NULL,
-	  "event-clipboard-copy" },
-
-	{ "event-popup-clipboard-cut",
-	  NULL,
-	  "event-clipboard-cut" },
-
-	{ "event-popup-clipboard-paste",
-	  NULL,
-	  "event-clipboard-paste" },
-
 	{ "event-popup-copy",
 	  NULL,
 	  "event-copy" },
@@ -1750,9 +1711,6 @@ e_cal_shell_view_actions_init (ECalShellView *cal_shell_view)
 	gtk_action_set_visible (action, FALSE);
 	e_shell_searchbar_set_search_option (
 		searchbar, GTK_RADIO_ACTION (action));
-	gtk_radio_action_set_current_value (
-		GTK_RADIO_ACTION (action),
-		CALENDAR_SEARCH_SUMMARY_CONTAINS);
 
 	/* Lockdown Printing Actions */
 	action_group = ACTION_GROUP (LOCKDOWN_PRINTING);
@@ -1786,9 +1744,6 @@ e_cal_shell_view_actions_init (ECalShellView *cal_shell_view)
 	action = ACTION (CALENDAR_VIEW_WORKWEEK);
 	g_object_set (action, "is-important", TRUE, NULL);
 
-	action = ACTION (EVENT_DELETE);
-	g_object_set (action, "short-label", _("Delete"), NULL);
-
 	g_signal_connect (
 		ACTION (GAL_SAVE_CUSTOM_VIEW), "activate",
 		G_CALLBACK (action_gal_save_custom_view_cb), cal_shell_view);
@@ -1818,13 +1773,13 @@ e_cal_shell_view_update_search_filter (ECalShellView *cal_shell_view)
 	action_group = ACTION_GROUP (CALENDAR_FILTER);
 	e_action_group_remove_all_actions (action_group);
 
-	/* Add the standard filter actions. */
+	/* Add the standard filter actions.  No callback is needed
+	 * because changes in the EActionComboBox are detected and
+	 * handled by EShellSearchbar. */
 	gtk_action_group_add_radio_actions (
 		action_group, calendar_filter_entries,
 		G_N_ELEMENTS (calendar_filter_entries),
-		CALENDAR_FILTER_ANY_CATEGORY,
-		G_CALLBACK (action_search_filter_cb),
-		cal_shell_view);
+		CALENDAR_FILTER_ANY_CATEGORY, NULL, NULL);
 
 	/* Retrieve the radio group from an action we just added. */
 	list = gtk_action_group_list_actions (action_group);
@@ -1875,10 +1830,13 @@ e_cal_shell_view_update_search_filter (ECalShellView *cal_shell_view)
 	}
 	g_list_free (list);
 
-	/* Use any action in the group; doesn't matter which. */
 	cal_shell_content = cal_shell_view->priv->cal_shell_content;
 	searchbar = e_cal_shell_content_get_searchbar (cal_shell_content);
 	combo_box = e_shell_searchbar_get_filter_combo_box (searchbar);
+
+	e_shell_view_block_execute_search (shell_view);
+
+	/* Use any action in the group; doesn't matter which. */
 	e_action_combo_box_set_action (combo_box, radio_action);
 
 	ii = CALENDAR_FILTER_UNMATCHED;
@@ -1886,4 +1844,6 @@ e_cal_shell_view_update_search_filter (ECalShellView *cal_shell_view)
 
 	ii = CALENDAR_FILTER_NEXT_7_DAYS_APPOINTMENTS;
 	e_action_combo_box_add_separator_after (combo_box, ii);
+
+	e_shell_view_unblock_execute_search (shell_view);
 }
