@@ -23,6 +23,23 @@
 
 #include "widgets/menus/gal-view-factory-etable.h"
 
+static void
+task_shell_view_model_row_appended_cb (ETaskShellView *task_shell_view,
+                                       ECalModel *model)
+{
+	ETaskShellSidebar *task_shell_sidebar;
+	ECal *client;
+	ESource *source;
+
+	/* This is the "Click to Add" handler. */
+
+	client = e_cal_model_get_default_client (model);
+	source = e_cal_get_source (client);
+
+	task_shell_sidebar = task_shell_view->priv->task_shell_sidebar;
+	e_task_shell_sidebar_add_source (task_shell_sidebar, source);
+}
+
 static void
 task_shell_view_process_completed_tasks (ETaskShellView *task_shell_view)
 {
@@ -56,27 +73,6 @@ task_shell_view_table_popup_event_cb (EShellView *shell_view,
 	e_shell_view_show_popup_menu (shell_view, widget_path, event);
 }
 
-static void
-task_shell_view_table_user_created_cb (ETaskShellView *task_shell_view,
-                                       ETaskTable *task_table)
-{
-	ETaskShellSidebar *task_shell_sidebar;
-	ECalModel *model;
-	ECal *client;
-	ESource *source;
-
-	/* This is the "Click to Add" handler. */
-
-	model = e_task_table_get_model (task_table);
-	client = e_cal_model_get_default_client (model);
-	source = e_cal_get_source (client);
-
-	task_shell_sidebar = task_shell_view->priv->task_shell_sidebar;
-	e_task_shell_sidebar_add_source (task_shell_sidebar, source);
-
-	e_cal_model_add_client (model, client);
-}
-
 static void
 task_shell_view_selector_client_added_cb (ETaskShellView *task_shell_view,
                                           ECal *client)
@@ -218,7 +214,6 @@ e_task_shell_view_private_constructed (ETaskShellView *task_shell_view)
 	EShellBackend *shell_backend;
 	EShellContent *shell_content;
 	EShellSidebar *shell_sidebar;
-	EShellTaskbar *shell_taskbar;
 	EShellSettings *shell_settings;
 	EShellWindow *shell_window;
 	ETaskTable *task_table;
@@ -229,7 +224,6 @@ e_task_shell_view_private_constructed (ETaskShellView *task_shell_view)
 	shell_backend = e_shell_view_get_shell_backend (shell_view);
 	shell_content = e_shell_view_get_shell_content (shell_view);
 	shell_sidebar = e_shell_view_get_shell_sidebar (shell_view);
-	shell_taskbar = e_shell_view_get_shell_taskbar (shell_view);
 	shell_window = e_shell_view_get_shell_window (shell_view);
 
 	shell = e_shell_window_get_shell (shell_window);
@@ -255,6 +249,11 @@ e_task_shell_view_private_constructed (ETaskShellView *task_shell_view)
 		G_CALLBACK (e_task_shell_view_update_timezone),
 		task_shell_view);
 
+	g_signal_connect_swapped (
+		model, "row-appended",
+		G_CALLBACK (task_shell_view_model_row_appended_cb),
+		task_shell_view);
+
 	g_signal_connect_swapped (
 		task_table, "open-component",
 		G_CALLBACK (e_task_shell_view_open_task),
@@ -280,11 +279,6 @@ e_task_shell_view_private_constructed (ETaskShellView *task_shell_view)
 		G_CALLBACK (e_task_shell_view_set_status_message),
 		task_shell_view);
 
-	g_signal_connect_swapped (
-		task_table, "user-created",
-		G_CALLBACK (task_shell_view_table_user_created_cb),
-		task_shell_view);
-
 	g_signal_connect_swapped (
 		model, "model-changed",
 		G_CALLBACK (e_task_shell_view_update_sidebar),
@@ -330,11 +324,15 @@ e_task_shell_view_private_constructed (ETaskShellView *task_shell_view)
 		task_shell_view);
 
 	/* Listen for configuration changes. */
-
 	e_mutual_binding_new (
 		shell_settings, "cal-confirm-purge",
 		task_shell_view, "confirm-purge");
 
+	/* Keep the ECalModel in sync with the sidebar. */
+	e_binding_new (
+		shell_sidebar, "default-client",
+		model, "default-client");
+
 	/* Hide Completed Tasks (enable/units/value) */
 	g_signal_connect_swapped (
 		shell_settings, "notify::cal-hide-completed-tasks",
@@ -582,18 +580,23 @@ e_task_shell_view_update_timezone (ETaskShellView *task_shell_view)
 	ETaskShellContent *task_shell_content;
 	ETaskShellSidebar *task_shell_sidebar;
 	ECalComponentPreview *task_preview;
+	EPreviewPane *preview_pane;
+	EWebView *web_view;
 	icaltimezone *timezone;
 	ECalModel *model;
 	GList *clients, *iter;
 
 	task_shell_content = task_shell_view->priv->task_shell_content;
-	task_preview = e_task_shell_content_get_task_preview (task_shell_content);
+	preview_pane = e_task_shell_content_get_preview_pane (task_shell_content);
 	model = e_task_shell_content_get_task_model (task_shell_content);
 	timezone = e_cal_model_get_timezone (model);
 
 	task_shell_sidebar = task_shell_view->priv->task_shell_sidebar;
 	clients = e_task_shell_sidebar_get_clients (task_shell_sidebar);
 
+	web_view = e_preview_pane_get_web_view (preview_pane);
+	task_preview = E_CAL_COMPONENT_PREVIEW (web_view);
+
 	for (iter = clients; iter != NULL; iter = iter->next) {
 		ECal *client = iter->data;
 
