@@ -179,7 +179,7 @@ mail_shell_view_key_press_event_cb (EMailShellView *mail_shell_view,
 	return TRUE;
 }
 
-static gint
+static gboolean
 mail_shell_view_message_list_key_press_cb (EMailShellView *mail_shell_view,
                                            gint row,
                                            ETreePath path,
@@ -593,6 +593,8 @@ e_mail_shell_view_private_constructed (EMailShellView *mail_shell_view)
 	context = E_SHELL_VIEW_GET_CLASS (shell_view)->search_context;
 	source = E_FILTER_SOURCE_DEMAND;
 	while ((rule = e_rule_context_next_rule (context, rule, source))) {
+		if (!rule->system)
+			continue;
 		g_assert (ii < MAIL_NUM_SEARCH_RULES);
 		priv->search_rules[ii++] = g_object_ref (rule);
 	}
