@@ -29,7 +29,10 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gconf/gconf-client.h>
+
+#ifdef HAVE_CANBERRA
 #include <canberra-gtk.h>
+#endif
 
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
@@ -116,7 +119,7 @@ static DBusConnection *bus = NULL;
 static gboolean init_dbus (void);
 
 static void
-send_dbus_message (const gchar *name, const gchar *data, guint new)
+send_dbus_message (const gchar *name, const gchar *data, guint new, const gchar *msg_uid, const gchar *msg_sender, const gchar *msg_subject)
 {
 	DBusMessage *message;
 
@@ -134,6 +137,19 @@ send_dbus_message (const gchar *name, const gchar *data, guint new)
 					  DBUS_TYPE_INVALID);
 	}
 
+	#define add_named_param(name, value)	\
+		if (value) {	\
+			gchar *val;	\
+			val = g_strconcat (name, ":", value, NULL);	\
+			dbus_message_append_args (message, DBUS_TYPE_STRING, &val, DBUS_TYPE_INVALID);	\
+		}
+
+	add_named_param ("msg_uid", msg_uid);
+	add_named_param ("msg_sender", msg_sender);
+	add_named_param ("msg_subject", msg_subject);
+
+	#undef add_named_param
+
 	/* Sends the message */
 	dbus_connection_send (bus, message, NULL);
 
@@ -196,14 +212,14 @@ static void
 new_notify_dbus (EMEventTargetFolder *t)
 {
 	if (bus != NULL)
-		send_dbus_message ("Newmail", t->uri, t->new);
+		send_dbus_message ("Newmail", t->uri, t->new, t->msg_uid, t->msg_sender, t->msg_subject);
 }
 
 static void
 read_notify_dbus (EMEventTargetMessage *t)
 {
 	if (bus != NULL)
-		send_dbus_message ("MessageReading", t->folder->name, 0);
+		send_dbus_message ("MessageReading", t->folder->name, 0, NULL, NULL, NULL);
 }
 
 static void
@@ -449,7 +465,7 @@ can_support_actions (void)
 static void
 new_notify_status (EMEventTargetFolder *t)
 {
-	gchar *msg;
+	gchar *msg, *safetext;
 	gboolean new_icon = !status_icon;
 
 	if (new_icon) {
@@ -462,11 +478,50 @@ new_notify_status (EMEventTargetFolder *t)
 		g_strdup (t->uri), (GDestroyNotify) g_free);
 
 	if (!status_count) {
+		EAccount *account;
+		gchar *name = t->name;
+
+		account = mail_config_get_account_by_source_url (t->uri);
+
+		if (account != NULL) {
+			name = g_strdup_printf (
+				"%s/%s", e_account_get_string (
+				account, E_ACCOUNT_NAME), name);
+		}
+
 		status_count = t->new;
-		/* To translators: '%d' is the number of mails recieved and '%s' is the name of the folder*/
+
+		/* To translators: '%d' is the count of mails received and '%s' is the name of the folder*/
 		msg = g_strdup_printf (ngettext ("You have received %d new message\nin %s.",
 						 "You have received %d new messages\nin %s.",
-						 status_count),status_count, t->name);
+						 status_count), status_count, name);
+
+		if (name != t->name)
+			g_free (name);
+
+		if (t->msg_sender) {
+			gchar *tmp, *str;
+
+			/* To Translators: "From:" is preceding a new mail sender address, like "From: user@example.com" */
+			str = g_strdup_printf (_("From: %s"), t->msg_sender);
+			tmp = g_strconcat (msg, "\n", str, NULL);
+
+			g_free (msg);
+			g_free (str);
+			msg = tmp;
+		}
+
+		if (t->msg_subject) {
+			gchar *tmp, *str;
+
+			/* To Translators: "Subject:" is preceding a new mail subject, like "Subject: It happened again" */
+			str = g_strdup_printf (_("Subject: %s"), t->msg_subject);
+			tmp = g_strconcat (msg, "\n", str, NULL);
+
+			g_free (msg);
+			g_free (str);
+			msg = tmp;
+		}
 	} else {
 		status_count += t->new;
 		msg = g_strdup_printf (ngettext ("You have received %d new message.",
@@ -485,13 +540,14 @@ new_notify_status (EMEventTargetFolder *t)
 #ifdef HAVE_LIBNOTIFY
 	/* Now check whether we're supposed to send notifications */
 	if (is_part_enabled (GCONF_KEY_STATUS_NOTIFICATION)) {
+		safetext = g_markup_escape_text(msg, strlen(msg));
 		if (notify) {
-			notify_notification_update (notify, _("New email"), msg, "mail-unread");
+			notify_notification_update (notify, _("New email"), safetext, "mail-unread");
 		} else {
 			if (!notify_init ("evolution-mail-notification"))
 				fprintf (stderr,"notify init error");
 
-			notify  = notify_notification_new (_("New email"), msg, "mail-unread", NULL);
+			notify  = notify_notification_new (_("New email"), safetext, "mail-unread", NULL);
 			notify_notification_attach_to_status_icon (notify, status_icon);
 
 			/* Check if actions are supported */
@@ -502,6 +558,7 @@ new_notify_status (EMEventTargetFolder *t)
 				g_timeout_add (500, notification_callback, notify);
 			}
 		}
+		g_free(safetext);
 	}
 #endif
 
@@ -607,13 +664,16 @@ get_config_widget_status (void)
 #define GCONF_KEY_SOUND_PLAY_FILE	GCONF_KEY_ROOT "sound-play-file"
 #define GCONF_KEY_SOUND_USE_THEME       GCONF_KEY_ROOT "sound-use-theme"
 
+#ifdef HAVE_CANBERRA
 static ca_context *mailnotification = NULL;
+#endif
 
 static void
 do_play_sound (gboolean beep, gboolean use_theme, const gchar *file)
 {
 	if (!beep) {
-		if ( (file || *file) && !use_theme )
+#ifdef HAVE_CANBERRA
+		if (!use_theme && file && *file)
 			ca_context_play(mailnotification, 0,
 			CA_PROP_MEDIA_FILENAME, file,
 			NULL);
@@ -621,6 +681,7 @@ do_play_sound (gboolean beep, gboolean use_theme, const gchar *file)
 			ca_context_play(mailnotification, 0,
 			CA_PROP_EVENT_ID,"message-new-email",
 			NULL);
+#endif
 	}
 	else
 		gdk_beep();
@@ -726,6 +787,7 @@ read_notify_sound (EMEventTargetMessage *t)
 static void
 enable_sound (gint enable)
 {
+#ifdef HAVE_CANBERRA
 	if (enable) {
 		ca_context_create(&mailnotification);
 		ca_context_change_props(
@@ -736,6 +798,7 @@ enable_sound (gint enable)
 	}
 	else
 		ca_context_destroy(mailnotification);
+#endif
 }
 
 static GtkWidget *
