@@ -593,7 +593,7 @@ et_focus (GtkWidget *container, GtkDirectionType direction)
 static void
 set_header_canvas_width (ETable *e_table)
 {
-	double oldwidth, oldheight, width;
+	gdouble oldwidth, oldheight, width;
 
 	if (!(e_table->header_item && e_table->header_canvas && e_table->table_canvas))
 		return;
@@ -734,6 +734,8 @@ table_canvas_size_allocate (GtkWidget *widget, GtkAllocation *alloc,
 	if (e_table->reflow_idle_id)
 		g_source_remove(e_table->reflow_idle_id);
 	table_canvas_reflow_idle(e_table);
+
+	e_table->size_allocated = TRUE;
 }
 
 static void
@@ -778,26 +780,26 @@ group_double_click (ETableGroup *etg, gint row, gint col, GdkEvent *event, ETabl
 	g_signal_emit (G_OBJECT (et), et_signals [DOUBLE_CLICK], 0, row, col, event);
 }
 
-static gint
+static gboolean
 group_right_click (ETableGroup *etg, gint row, gint col, GdkEvent *event, ETable *et)
 {
-	gint return_val = 0;
+	gboolean return_val = FALSE;
 	g_signal_emit (G_OBJECT (et), et_signals [RIGHT_CLICK], 0, row, col, event, &return_val);
 	return return_val;
 }
 
-static gint
+static gboolean
 group_click (ETableGroup *etg, gint row, gint col, GdkEvent *event, ETable *et)
 {
-	gint return_val = 0;
+	gboolean return_val = 0;
 	g_signal_emit (G_OBJECT (et), et_signals [CLICK], 0, row, col, event, &return_val);
 	return return_val;
 }
 
-static gint
+static gboolean
 group_key_press (ETableGroup *etg, gint row, gint col, GdkEvent *event, ETable *et)
 {
-	gint return_val = 0;
+	gboolean return_val = FALSE;
 	GdkEventKey *key = (GdkEventKey *) event;
 	gint y, row_local, col_local;
 	GtkAdjustment *vadj;
@@ -852,10 +854,10 @@ group_key_press (ETableGroup *etg, gint row, gint col, GdkEvent *event, ETable *
 	return return_val;
 }
 
-static gint
+static gboolean
 group_start_drag (ETableGroup *etg, gint row, gint col, GdkEvent *event, ETable *et)
 {
-	gint return_val = 0;
+	gboolean return_val = TRUE;
 	g_signal_emit (G_OBJECT (et), et_signals [START_DRAG], 0,
 		       row, col, event, &return_val);
 	return return_val;
@@ -992,16 +994,24 @@ changed_idle (gpointer data)
 {
 	ETable *et = E_TABLE (data);
 
-	if (et->need_rebuild) {
+	/* Wait until we have a valid size allocation. */
+	if (et->need_rebuild && et->size_allocated) {
+		GtkWidget *widget;
+		GtkAllocation allocation;
+
 		if (et->group)
 			gtk_object_destroy (GTK_OBJECT (et->group));
 		et_build_groups(et);
-		g_object_set (et->canvas_vbox,
-			      "width", (double) GTK_WIDGET (et->table_canvas)->allocation.width,
-			      NULL);
 
-		if (GTK_WIDGET_REALIZED(et->table_canvas))
-			table_canvas_size_allocate (GTK_WIDGET(et->table_canvas), &GTK_WIDGET(et->table_canvas)->allocation, et);
+		widget = GTK_WIDGET (et->table_canvas);
+		gtk_widget_get_allocation (widget, &allocation);
+
+		g_object_set (
+			et->canvas_vbox,
+			"width", (gdouble) allocation.width,
+			NULL);
+
+		table_canvas_size_allocate (widget, &allocation, et);
 	}
 
 	et->need_rebuild = 0;
@@ -1024,10 +1034,10 @@ et_canvas_realize (GtkWidget *canvas, ETable *e_table)
 	set_header_width (e_table);
 }
 
-static gint
+static gboolean
 white_item_event (GnomeCanvasItem *white_item, GdkEvent *event, ETable *e_table)
 {
-	gint return_val = 0;
+	gboolean return_val = 0;
 	g_signal_emit (GTK_OBJECT (e_table), et_signals [WHITE_SPACE_EVENT], 0,
 		       event, &return_val);
 	return return_val;
@@ -1308,7 +1318,7 @@ e_table_set_state_object(ETable *e_table, ETableState *state)
 
 	connect_header (e_table, state);
 
-	g_value_set_double (val, (double) (GTK_WIDGET(e_table->table_canvas)->allocation.width));
+	g_value_set_double (val, (gdouble) (GTK_WIDGET(e_table->table_canvas)->allocation.width));
 	g_object_set_property (G_OBJECT (e_table->header), "width", val);
 	g_free (val);
 
@@ -2586,10 +2596,10 @@ e_table_drag_highlight (ETable *table,
 						       NULL);
 		}
 		gnome_canvas_item_set (table->drop_highlight,
-				       "x1", (double) x,
-				       "x2", (double) x + width - 1,
-				       "y1", (double) y,
-				       "y2", (double) y + height - 1,
+				       "x1", (gdouble) x,
+				       "x2", (gdouble) x + width - 1,
+				       "y1", (gdouble) y,
+				       "y2", (gdouble) y + height - 1,
 				       NULL);
 	} else {
 		if (table->drop_highlight) {
@@ -2884,7 +2894,7 @@ scroll_timeout (gpointer data)
 	ETable *et = data;
 	gint dx = 0, dy = 0;
 	GtkAdjustment *h, *v;
-	double hvalue, vvalue;
+	gdouble hvalue, vvalue;
 
 	if (et->scroll_direction & ET_SCROLL_DOWN)
 		dy += 20;
@@ -3147,9 +3157,9 @@ e_table_class_init (ETableClass *class)
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ETableClass, right_click),
-			      NULL, NULL,
-			      e_marshal_INT__INT_INT_BOXED,
-			      G_TYPE_INT, 3, G_TYPE_INT,
+			      g_signal_accumulator_true_handled, NULL,
+			      e_marshal_BOOLEAN__INT_INT_BOXED,
+			      G_TYPE_BOOLEAN, 3, G_TYPE_INT,
 			      G_TYPE_INT, GDK_TYPE_EVENT);
 
 	et_signals [CLICK] =
@@ -3157,9 +3167,9 @@ e_table_class_init (ETableClass *class)
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ETableClass, click),
-			      NULL, NULL,
-			      e_marshal_INT__INT_INT_BOXED,
-			      G_TYPE_INT, 3, G_TYPE_INT,
+			      g_signal_accumulator_true_handled, NULL,
+			      e_marshal_BOOLEAN__INT_INT_BOXED,
+			      G_TYPE_BOOLEAN, 3, G_TYPE_INT,
 			      G_TYPE_INT, GDK_TYPE_EVENT);
 
 	et_signals [KEY_PRESS] =
@@ -3167,9 +3177,9 @@ e_table_class_init (ETableClass *class)
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ETableClass, key_press),
-			      NULL, NULL,
-			      e_marshal_INT__INT_INT_BOXED,
-			      G_TYPE_INT, 3, G_TYPE_INT,
+			      g_signal_accumulator_true_handled, NULL,
+			      e_marshal_BOOLEAN__INT_INT_BOXED,
+			      G_TYPE_BOOLEAN, 3, G_TYPE_INT,
 			      G_TYPE_INT, GDK_TYPE_EVENT);
 
 	et_signals [START_DRAG] =
@@ -3177,9 +3187,9 @@ e_table_class_init (ETableClass *class)
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ETableClass, start_drag),
-			      NULL, NULL,
-			      e_marshal_INT__INT_INT_BOXED,
-			      G_TYPE_INT, 3, G_TYPE_INT,
+			      g_signal_accumulator_true_handled, NULL,
+			      e_marshal_BOOLEAN__INT_INT_BOXED,
+			      G_TYPE_BOOLEAN, 3, G_TYPE_INT,
 			      G_TYPE_INT, GDK_TYPE_EVENT);
 
 	et_signals [STATE_CHANGE] =
@@ -3196,9 +3206,9 @@ e_table_class_init (ETableClass *class)
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ETableClass, white_space_event),
-			      NULL, NULL,
-			      e_marshal_INT__BOXED,
-			      G_TYPE_INT, 1, GDK_TYPE_EVENT);
+			      g_signal_accumulator_true_handled, NULL,
+			      e_marshal_BOOLEAN__BOXED,
+			      G_TYPE_BOOLEAN, 1, GDK_TYPE_EVENT);
 
 	et_signals[TABLE_DRAG_BEGIN] =
 		g_signal_new ("table_drag_begin",
